==> Evergreen-ILS-3.15.7.tar.gz: Evergreen-ILS-3.15.7/Open-ILS/web/js/dojo/openils/opac/nls/fi-fi/opac.js <==
{
    ":BARCODE_PROMPT": "Asiakastunnus: ",
    ":USERNAME_PROMPT": "Username: ",
    ":CANCEL_BUTTON_LABEL": "Peruuta",
    ":SUBMIT_BUTTON_LABEL": "L\u00e4het\u00e4",
    ":OK": "OK",
    ":PWD_RESET_RESPONSE_TITLE": "Salasanan uusintavastaus",
    ":PWD_RESET_SUBMIT_SUCCESS": "Salasanan uusintapyynt\u00f6\u00e4si k\u00e4sitell\u00e4\u00e4n. Jos tiliisi on liitetty kelvollinen s\u00e4hk\u00f6postiosoite, saat pian s\u00e4hk\u00f6postin, jossa on lis\u00e4ohjeita salasanan uusimisesta.",
    ":PWD_RESET_SUBMIT_ERROR": "J\u00e4rjestelm\u00e4 ei pystynyt k\u00e4sittelem\u00e4\u00e4n salasanan uusintapyynt\u00f6\u00e4si. Yrit\u00e4 uudelleen tai ota yhteytt\u00e4 lainaushenkil\u00f6kuntaan, jos tarvitset apua.",
    ":PWD_RESET_SUBMIT_STATUS": "L\u00e4hetet\u00e4\u00e4n pyynt\u00f6\u00e4...",
    ":PWD_RESET_FORGOT_PROMPT": "Unohditko salasanasi?",
    ":PWD_RESET_FORM_TITLE": "Pyyd\u00e4 salasanan uusintaa",
    ":PWD_RESET_SUBMIT_PROMPT": "To begin the password reset process, enter either your barcode or username in the form below and click 'Submit'",
    ":CREATE_MFHD": "Lis\u00e4\u00e4 MFHD-tietue",
    ":CREATED_MFHD_RECORD": "MFHD-tietue luotu kohteelle ${0}",
    ":DELETE_MFHD": "Tuhoa tietue",
    ":DELETE_MFHD_CONFIRM": "Haluatko varmasti tuhota kausijulkaisutietueen?",
    ":DELETED_MFHD_RECORD": "MFHD-tietue ${0} tuhottu",
    ":EDIT_MFHD_RECORD": "Muokkaa tietuetta",
    ":EDIT_MFHD_MENU": "Muokkaa varauksia",
    ":EDIT_PROPERTIES": "Muokkaa ominaisuuksia",
    ":BASIC_HOLDINGS": "Niteet",
    ":BASIC_HOLDINGS_ADD": "Ylim\u00e4\u00e4r\u00e4iset teostiedot",
    ":INDEX_HOLDINGS": "Hakemistot",
    ":INDEX_HOLDINGS_ADD": "Ylim\u00e4\u00e4r\u00e4iset hakemistotiedot",
    ":CURRENT_HOLDINGS": "Nykyinen vuosikerta",
    ":CURRENT_INDEXES": "Nykyiset hakemistot",
    ":CURRENT_SUPPLEMENTS": "Nykyiset t\u00e4ydennykset",
    ":HOLDINGS_TABLE_CAPTION": "Varausten yhteenveto (${0})",
    ":INCOMPLETE_VOLUMES": "Ep\u00e4t\u00e4ydelliset vuosikerrat",
    ":MISSING_VOLUMES": "Puuttuvat vuosikerrat",
    ":ONLINE_VOLUMES": "Online-tilassa olevat vuosikerrat",
    ":SAVE_MFHD_LABEL": "Tallenna MFHD",
    ":SUPPLEMENT_HOLDINGS": "T\u00e4ydennykset",
    ":SUPPLEMENT_HOLDINGS_ADD": "Ylim\u00e4\u00e4r\u00e4iset t\u00e4ydennystiedot",
    ":PLACE_HOLD": "Varaa",
    ":HOLD_STATUS_PLURAL": "varaus # ${0} / ${1} varauksesta yhteens\u00e4 ja ${2} mahdollisesta niteest\u00e4",
    ":HOLD_STATUS_SINGULAR": "varaus # ${0} / ${0} varauksesta yhteens\u00e4 ja ${2} mahdollisesta niteest\u00e4",
    ":MORE": "Lis\u00e4\u00e4",
    ":MORE_COPIES_FULL_RECORD": "... lis\u00e4\u00e4 kappaleita listattu t\u00e4ydess\u00e4 tietueessa",
    ":SOURCE_CANNOT_HAVE_COPIES": "Tietueisiin kohteesta ${0} ei voi kuulua niteit\u00e4."
}

==> Evergreen-ILS-3.16.3.tar.gz: Evergreen-ILS-3.16.3/Open-ILS/web/js/dojo/openils/opac/nls/fi-fi/opac.js <==
{
    ":BARCODE_PROMPT": "Asiakastunnus: ",
    ":USERNAME_PROMPT": "K\u00e4ytt\u00e4j\u00e4tunnus: ",
    ":CANCEL_BUTTON_LABEL": "Peruuta",
    ":SUBMIT_BUTTON_LABEL": "L\u00e4het\u00e4",
    ":OK": "OK",
    ":PWD_RESET_RESPONSE_TITLE": "Salasanan uusintavastaus",
    ":PWD_RESET_SUBMIT_SUCCESS": "Salasanan uusintapyynt\u00f6\u00e4si k\u00e4sitell\u00e4\u00e4n. Jos tiliisi on liitetty kelvollinen s\u00e4hk\u00f6postiosoite, saat pian s\u00e4hk\u00f6postin, jossa on lis\u00e4ohjeita salasanan uusimisesta.",
    ":PWD_RESET_SUBMIT_ERROR": "J\u00e4rjestelm\u00e4 ei pystynyt k\u00e4sittelem\u00e4\u00e4n salasanan uusintapyynt\u00f6\u00e4si. Yrit\u00e4 uudelleen tai ota yhteytt\u00e4 lainaushenkil\u00f6kuntaan, jos tarvitset apua.",
    ":PWD_RESET_SUBMIT_STATUS": "L\u00e4hetet\u00e4\u00e4n pyynt\u00f6\u00e4...",
    ":PWD_RESET_FORGOT_PROMPT": "Unohditko salasanasi?",
    ":PWD_RESET_FORM_TITLE": "Pyyd\u00e4 salasanan uusintaa",
    ":PWD_RESET_SUBMIT_PROMPT": "Jos haluat aloittaa salasanan uusimisen, sy\u00f6t\u00e4 joko asiakastunnus/k\u00e4ytt\u00e4j\u00e4tunnus alla olevaan lomakkeeseen ja napsauta 'L\u00e4het\u00e4'",
    ":CREATE_MFHD": "Lis\u00e4\u00e4 MFHD-tietue",
    ":CREATED_MFHD_RECORD": "MFHD-tietue luotu kohteelle ${0}",
    ":DELETE_MFHD": "Tuhoa tietue",
    ":DELETE_MFHD_CONFIRM": "Haluatko varmasti tuhota kausijulkaisutietueen?",
    ":DELETED_MFHD_RECORD": "MFHD-tietue ${0} tuhottu",
    ":EDIT_MFHD_RECORD": "Muokkaa tietuetta",
    ":EDIT_MFHD_MENU": "Muokkaa varauksia",
    ":EDIT_PROPERTIES": "Muokkaa ominaisuuksia",
    ":BASIC_HOLDINGS": "Niteet",
    ":BASIC_HOLDINGS_ADD": "Ylim\u00e4\u00e4r\u00e4iset teostiedot",
    ":INDEX_HOLDINGS": "Hakemistot",
    ":INDEX_HOLDINGS_ADD": "Ylim\u00e4\u00e4r\u00e4iset hakemistotiedot",
    ":CURRENT_HOLDINGS": "Nykyinen vuosikerta",
    ":CURRENT_INDEXES": "Nykyiset hakemistot",
    ":CURRENT_SUPPLEMENTS": "Nykyiset t\u00e4ydennykset",
    ":HOLDINGS_TABLE_CAPTION": "Varausten yhteenveto (${0})",
    ":INCOMPLETE_VOLUMES": "Ep\u00e4t\u00e4ydelliset vuosikerrat",
    ":MISSING_VOLUMES": "Puuttuvat vuosikerrat",
    ":ONLINE_VOLUMES": "Online-tilassa olevat vuosikerrat",
    ":SAVE_MFHD_LABEL": "Tallenna MFHD",
    ":SUPPLEMENT_HOLDINGS": "T\u00e4ydennykset",
    ":SUPPLEMENT_HOLDINGS_ADD": "Ylim\u00e4\u00e4r\u00e4iset t\u00e4ydennystiedot",
    ":PLACE_HOLD": "Varaa",
    ":HOLD_STATUS_PLURAL": "varaus # ${0} / ${1} varauksesta yhteens\u00e4 ja ${2} mahdollisesta niteest\u00e4",
    ":HOLD_STATUS_SINGULAR": "varaus # ${0} / ${0} varauksesta yhteens\u00e4 ja ${2} mahdollisesta niteest\u00e4",
    ":MORE": "Lis\u00e4\u00e4",
    ":MORE_COPIES_FULL_RECORD": "... lis\u00e4\u00e4 kappaleita listattu t\u00e4ydess\u00e4 tietueessa",
    ":SOURCE_CANNOT_HAVE_COPIES": "Tietueisiin kohteesta ${0} ei voi kuulua niteit\u00e4."
}
